@@ -459,17 +459,14 @@ static void
 cpufreq_applet_about_cb (GtkAction     *action,
                          CPUFreqApplet *applet)
 {
-        char copyright[] = \
-                "Copyright \xc2\xa9 2012-2018 MATE developers\n"
-                "Copyright \xC2\xA9 2004 Carlos Garcia Campos";
-
         static const gchar *const authors[] = {
                 "Carlos Garcia Campos <carlosgc@gnome.org>",
                 NULL
         };
-        static const gchar *const documenters[] = {
+        static const gchar* documenters[] = {
                 "Carlos Garcia Campos <carlosgc@gnome.org>",
                 "Davyd Madeley <davyd@madeley.id.au>",
+                N_("MATE Documentation Team"),
                 NULL
         };
         static const gchar *const artists[] = {
@@ -477,9 +474,17 @@ cpufreq_applet_about_cb (GtkAction     *action,
                 NULL
         };
 
+#ifdef ENABLE_NLS
+	const char **p;
+	for (p = documenters; *p; ++p)
+		*p = _(*p);
+#endif
+
         gtk_show_about_dialog (NULL,
+                               "title",         _("About CPU Frequency Scaling Monitor"),
                                "version",       VERSION,
-                               "copyright",     copyright,
+                               "copyright",     _("Copyright \xC2\xA9 2004 Carlos Garcia Campos\n"
+                                                  "Copyright \xc2\xa9 2012-2019 MATE developers"),
                                "comments",      _("This utility shows the current CPU "
                                                   "Frequency Scaling."),
                                "authors",       authors,
