@@ -160,22 +160,27 @@ about_cb (GtkAction   *action,
                 NULL
 	};
 
-    char copyright[] = \
-                "Copyright \xc2\xa9 2012-2018 MATE developers\n"
-                "Copyright \xC2\xA9 1999 Dave Camp";
-
 	const gchar *documenters[] = {
                 "Arjan Scherpenisse <acscherp@wins.uva.nl>",
                 "Telsa Gwynne <hobbit@aloss.ukuu.org.uk>",
-                "Sun GNOME Documentation Team <gdocteam@sun.com>",
+                N_("Sun GNOME Documentation Team <gdocteam@sun.com>"),
+                N_("MATE Documentation Team"),
 		NULL
 	};
 
+#ifdef ENABLE_NLS
+	const char **p;
+	for (p = documenters; *p; ++p)
+		*p = _(*p);
+#endif
+
 	gtk_show_about_dialog (NULL,
+		"title",              _("About Eyes"),
 		"version",            VERSION,
 		"comments",           _("A goofy set of eyes for the MATE "
 		                      "panel. They follow your mouse."),
-		"copyright",          copyright,
+		"copyright",          _("Copyright \xC2\xA9 1999 Dave Camp\n"
+		                        "Copyright \xc2\xa9 2012-2019 MATE developers"),
 		"authors",            authors,
 		"documenters",        documenters,
 		"translator-credits", _("translator-credits"),
