@@ -153,11 +153,7 @@ xstuff_zoom_animate (GtkWidget *widget, GdkRectangle *opt_rect)
 	GdkScreen    *gscreen;
 	GdkRectangle  rect, dest;
 	GtkAllocation allocation;
-#if GTK_CHECK_VERSION (3, 22, 0)
 	GdkMonitor   *monitor;
-#else
-	int           monitor;
-#endif
 
 	if (opt_rect)
 		rect = *opt_rect;
@@ -173,14 +169,9 @@ xstuff_zoom_animate (GtkWidget *widget, GdkRectangle *opt_rect)
 	}
 
 	gscreen = gtk_widget_get_screen (widget);
-#if GTK_CHECK_VERSION (3, 22, 0)
 	monitor = gdk_display_get_monitor_at_window (gdk_screen_get_display (gscreen),
 						     gtk_widget_get_window (widget));
 	gdk_monitor_get_geometry (monitor, &dest);
-#else
-	monitor = gdk_screen_get_monitor_at_window (gscreen, gtk_widget_get_window (widget));
-	gdk_screen_get_monitor_geometry (gscreen, monitor, &dest);
-#endif
 
 	draw_zoom_animation (gscreen,
 			     rect.x, rect.y, rect.width, rect.height,
